Computes ASPRE model prediction on a matrix X of covariates
Full ASPRE model from https://www.nejm.org/doi/suppl/10.1056/NEJMoa1704559/suppl_file/nejmoa1704559_appendix.pdf
Model is to predict gestational age at PE; that is, a higher score indicates a lower PE risk, so coefficients are negated for model to predict PE risk.
Usage
aspre(X)
Value
vector of scores.
Arguments
X
matrix, assumed to be output of sim_random_aspre with parameter params=params_aspre and transformed using add_aspre_interactions