Learn R Programming

OptHoldoutSize (version 0.1.0.1)

gen_base_coefs: Coefficients for imperfect risk score

Description

Generate coefficients corresponding to an imperfect risk score, interpretable as 'baseline' behaviour in the absence of a risk score

Usage

gen_base_coefs(coefs, noise = TRUE, num_vars = 2, max_base_powers = 1)

Value

Vector of coefficients

Arguments

coefs

Original coefficients

noise

Set to TRUE to add Gaussian noise to coefficients

num_vars

Number of variables at hand for baseline calculation

max_base_powers

If >1, return a matrix of coefficients, with successively more noise

Examples

Run this code

# See examples for model_predict

Run the code above in your browser using DataLab